$ErrorActionPreference = 'Stop'
Set-StrictMode -Version Latest

$TYPE = 'net7'
$VERSION = '1.18.6'
$DEST = "$(Get-Location)/cartographer"

New-Item -ItemType Directory -Path $DEST -Force | Out-Null
New-Item -ItemType Directory -Path html -Force | Out-Null
New-Item -ItemType Directory -Path map_data -Force | Out-Null
New-Item -ItemType Directory -Path "$DEST/cartographerData/ModConfig" -Force | Out-Null
New-Item -ItemType Directory -Path "$DEST/cartographerData/Mods" -Force | Out-Null

$SERVER = "vs_server_$VERSION.tar.gz"
$URL_SERVER = "https://cdn.vintagestory.at/gamefiles/$TYPE/vs_server_linux-x64_$VERSION.tar.gz"

if (-not (Test-Path $SERVER)) {
  Invoke-WebRequest -Uri $URL_SERVER -OutFile $SERVER
} else {
  if (-not Test-Path "$DEST/assets") {
    Expand-Archive -Path $SERVER -DestinationPath $DEST
  }
}

if ((Test-Path "serverconfig.json")) {
  Copy-Item "serverconfig.json" "$DEST/cartographerData/serverconfig.json"
} else {
  New-Item -ItemType File "serverconfig.json", "$DEST/cartographerData/serverconfig.json" | Out-Null
}

if ((Test-Path "servermagicnumbers.json")) {
  Copy-Item "servermagicnumbers.json" "$DEST/cartographerData/servermagicnumbers.json"
} else {
  New-Item -ItemType File "$DEST/cartographerData/servermagicnumbers.json" | Out-Null
}

Copy-Item "WebCartographerConfig.json" "$DEST/cartographerData/ModConfig/WebCartographerConfig.json"
Copy-Item "blockColorMapping.json" "$DEST/cartographerData/ModConfig/blockColorMapping.json"

if ((Test-Path "Mods")) {
  Copy-Item -Recurse "Mods" "$DEST/cartographerData/Mods"
}

docker compose up cartographer
docker compose up webmap -d

Copy-Item -Recurse "./map_data/world/" "./html/data/world/"
Copy-Item -Recurse "./map_data/geojson" "./html/data/"

Write-Output "Done creating webmap - Check it out at http://localhost:4242"
